@@ -72,7 +72,7 @@ def install_app(name: Text, log_level: Text):
     loop.run_until_complete(get_async_http_session().close())
 
 
-@entrypoint.command(name="login", short_help='To login to the neuralSpace platform')
+@entrypoint.command(name="login", short_help="To login to the neuralSpace platform")
 @click.option(
     "-e",
     "--email",
